@@ -1,19 +1,19 @@
 # Trichromat
 pal <- colour("bright")
-scales::show_col(pal(7))
+plot_scheme(pal(7))
 
 # Deuteranopia
 deu <- convert(pal, mode = "deuteranopia")
-scales::show_col(deu(7))
+plot_scheme(deu(7))
 
 # Protanopia
 pro <- convert(pal, mode = "protanopia")
-scales::show_col(pro(7))
+plot_scheme(pro(7))
 
 # Tritanopia
 tri <- convert(pal, mode = "tritanopia")
-scales::show_col(tri(7))
+plot_scheme(tri(7))
 
 # Achromatopsia
 ach <- convert(pal, mode = "achromatopsia")
-scales::show_col(ach(7))
+plot_scheme(ach(7))
